summaryrefslogtreecommitdiff
path: root/nuttx/configs/spark/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/spark/src/up_buttons.c')
-rw-r--r--nuttx/configs/spark/src/up_buttons.c14
1 files changed, 8 insertions, 6 deletions
diff --git a/nuttx/configs/spark/src/up_buttons.c b/nuttx/configs/spark/src/up_buttons.c
index 33791417a..ddba1e89e 100644
--- a/nuttx/configs/spark/src/up_buttons.c
+++ b/nuttx/configs/spark/src/up_buttons.c
@@ -1,7 +1,7 @@
/****************************************************************************
* configs/spark/src/up_buttons.c
*
- * Copyright (C) 2011-2013 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2011-2014 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
*
* Redistribution and use in source and binary forms, with or without
@@ -41,7 +41,9 @@
#include <stdint.h>
+#include <nuttx/arch.h>
#include <arch/board/board.h>
+
#include "spark.h"
#ifdef CONFIG_ARCH_BUTTONS
@@ -63,17 +65,17 @@
****************************************************************************/
/****************************************************************************
- * Name: up_buttoninit
+ * Name: board_button_initialize
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
-void up_buttoninit(void)
+void board_button_initialize(void)
{
/* Configure the GPIO pins as inputs. NOTE that EXTI interrupts are
* configured for all pins.
@@ -97,12 +99,12 @@ uint8_t up_buttons(void)
* Button support.
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After up_buttoninit() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
@@ -63,17 +65,17 @@
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -97,12 +99,12 @@ uint8_t up_buttons(void)
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -97,12 +99,12 @@ uint8_t up_buttons(void)
* handlers.
*
- * After up_buttoninit() has been called, up_buttons() may be called to
+ * After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT